%
%  Этот документ предоставляет пакет 'cmcherald' для
%  оформления статей в Вестнике Московского Университета, серия ВМК.
%


%
%   General info
%

\NeedsTeXFormat{LaTeX2e}[1994/12/01]
\ProvidesClass{cmcherald}
\LoadClass[twoside,11pt]{extarticle}



%
% Schoolbook font
%
%\RequirePackage{fouriernc}
\RequirePackage[T2A,T1]{fontenc}

%
%   Packages: general purpose
%

\RequirePackage[utf8]{inputenc}
\RequirePackage[english,russian]{babel}
\RequirePackage{boxedminipage}
\RequirePackage{indentfirst}
\RequirePackage{afterpage}
\RequirePackage{paralist}
\RequirePackage{url}
\RequirePackage{textcomp}
\RequirePackage{cite}
\RequirePackage{mdwlist}
\RequirePackage{bm}
\RequirePackage{graphicx}
\RequirePackage{float}
\RequirePackage[font=small,labelsep=period,bf]{caption}
\RequirePackage[bookmarksnumbered,pdfborder={0 0 0}]{hyperref}


%\captionsetup[figure]{name=Fig.}


%
%   Release info
%

\newcommand{\VOLUME}{V}
\newcommand{\NUMBER}{N}
\newcommand{\YEAR}{2019}
\newcommand{\YEARSHORT}{19}


%
%   Paper, printing area, headers and footers
%

\usepackage[%
    paperheight=11in,%279mm,%
    paperwidth=8.25in,%210mm,%
    %textwidth=174mm,
    textheight=234mm,%
    left=18mm,%
    top=2.5cm,%
    right=18mm,%
    %bottom=1.5cm,%
    headsep=0.3cm,%
    headheight=14pt,%
    footskip=0.5cm]{geometry}

\RequirePackage{fancyhdr}
\renewcommand{\headrulewidth}{0.5pt}
\pagestyle{fancy}       %   Default
\fancyhead[LE,RO]{\thepage}
\fancyfoot{}
%\fancyfoot[LE]{ВМУ, вычислительная математика и кибернетика, \No \NUMBER}

\fancypagestyle{titul}{%    %   For title pages
\fancyhead{}%
\lhead{{ВЕСТН. МОСК. УН-ТА. СЕР. 15. ВЫЧИСЛ. МАТЕМ. И КИБЕРН. \YEAR . \No \NUMBER}}%
\fancyfoot{}%

\renewcommand{\footrulewidth}{0.0pt}

}

%
%   Section formatting
%

\usepackage[tiny,compact]{titlesec}
\titleformat{\section}[runin]{\normalfont\bfseries}{\indent{\thesection.}}{0.5em}{}
\titleformat{\subsection}[runin]{\normalfont\bfseries}{\indent{\thesubsection.}}{0.5em}{}
%
%   Packages: math and so
%

\RequirePackage{amssymb}
\RequirePackage{amsmath}
\RequirePackage{amsthm}
\RequirePackage{amscd}

%
%   New commands for math
%

%   Many often-used, but absent in LaTeX objects

\DeclareMathOperator{\const}{const}
\DeclareMathOperator{\conv}{conv}
\DeclareMathOperator{\med}{med}
\DeclareMathOperator{\sgn}{sgn}
\DeclareMathOperator{\tr}{tr}
\DeclareMathOperator{\diag}{diag}


\renewcommand{\le}{\leqslant}
\renewcommand{\ge}{\geqslant}

\renewcommand{\leq}{\leqslant}
\renewcommand{\geq}{\geqslant}


%
%   Semi-automatic author system
%
\newcommand{\authors}{\small}

\newcounter{authorNum}
\setcounter{authorNum}{1}

\newcommand{\addAuthorInfo}[1]{%
\g@addto@macro\authors{\quad $^{\text{\arabic{authorNum}}}$\,#1 \addtocounter{authorNum}{1} \\\phantom{}}%
}

% Non-automatic part :(
\newcommand{\first}{$^1$\,}
\newcommand{\second}{$^2$\,}
\newcommand{\third}{$^3$\,}
\newcommand{\also}{\!$^,$}


%
%	Shapka
%
\newcommand{\thepapertitle}{TITLE IS NOT DEFINED}
\newcommand{\theauthorsfull}{FULL AUTHORS ARE NOT DEFINED}
\newcommand{\theauthorsshort}{SHORT AUTHORS ARE NOT DEFINED}
\newcommand{\theauthorsinfo}{{}}
\newcommand{\theabstract}{ABSTRACT IS NOT PROVIDED}
\newcommand{\theudk}{UNKNOWN!}


\newcommand{\paperTitle}[1]{\renewcommand{\thepapertitle}{#1}}
\newcommand{\paperUdk}[1]{\renewcommand{\theudk}{#1}}
\newcommand{\authorsFull}[1]{\renewcommand{\theauthorsfull}{#1}}
\newcommand{\authorsShort}[1]{\renewcommand{\theauthorsshort}{#1}}
\newcommand{\authorsInfo}[1]{\renewcommand{\theauthorsinfo}{#1}}
\newcommand{\paperAbstract}[1]{\renewcommand{\theabstract}{#1}}
\newcommand{\paperGrant}[1]{\newcommand{\thegrant}{#1}}
\newcommand{\paperKeywords}[1]{\newcommand{\thekeywords}{#1}}

%
%	Article header
%
\makeatletter
\renewcommand{\maketitle}{%                           
\thispagestyle{titul}
\vspace*{0.1cm}
\noindent {УДК \theudk }
\vspace*{0.1cm}
%
%   Authors
%

{\bf \theauthorsfull}

%
%   Arcticle title
%
\pdfbookmark[1]{Abstract}{AbstractReference}
\parbox[l]{0.7\textwidth}{\begin{flushleft}%
                    \noindent{%
			\ifcsname thegrant\endcsname%
				\large\bf \MakeUppercase{\thepapertitle}*
			\else%
				\large\bf \MakeUppercase{\thepapertitle}
			\fi%
			}% noindent 
                \end{flushleft}
}

%
%   Abstract
%

\begin{quotation}
\small\indent\theabstract
\end{quotation}

%
%	Keywords
%
\ifcsname thekeywords\endcsname%
	\begin{quotation}
	\small\indent \textit{Ключевые слова}: \thekeywords
	\end{quotation}
\else%
	
\fi

%
%   Appereance commands
%
\fancyhead[LO]{{\thepapertitle}}
\fancyhead[RE]{{\theauthorsshort}}

\IfFileExists{page}{\input{page}}{}

%
%   Bottom text: author info
%

\begin{figure}[b]
\makebox[\linewidth]{\rule{1in}{0.4pt}\hfill}

\authors
\ifcsname thegrant\endcsname%
	\quad* \thegrant\vspace{-1.5mm}
\else%
	\vspace{-5.5mm}
\fi%

\end{figure}

}
\makeatother

%
%   For reference commands
%

\renewcommand{\refname}{\begin{center}{СПИСОК ЛИТЕРАТУРЫ}\end{center}}

\newcommand{\source}{\item}

\newenvironment{references}%
	{\def\section*{\center{СПИСОК ЛИТЕРАТУРЫ}}%
	\pdfbookmark[1]{References}{ReferenceToReferences}
	\renewcommand{\refname}{}%
	%\begin{center}\textbf{REFERENCES}\end{center}%
	\begin{thebibliography}{00}}%
        {\end{thebibliography}}

%   No brackets, just number
\makeatletter
\renewcommand\@biblabel[1]{#1.}
\makeatother

%   Shorten the spaces
\let\oldbibliography\thebibliography
\renewcommand{\thebibliography}[1]{%
  \oldbibliography{#1}%
  \setlength{\itemsep}{-1.4pt}%
}


%
%   Theorems via AMS package
%

\newtheoremstyle{cmchTheorem}% name of the style to be used
  {3pt}% measure of space to leave above the theorem. E.g.: 3pt
  {3pt}% measure of space to leave below the theorem. E.g.: 3pt
  {\itshape}% name of font to use in the body of the theorem
  {\parindent}% measure of space to indent
  {}% name of head font
  {.}% punctuation between head and body
  {.5em}% space after theorem head; " " = normal interword space
  {}

\newtheoremstyle{cmchRemark}% name of the style to be used
  {2pt}% measure of space to leave above the theorem. E.g.: 3pt
  {2pt}% measure of space to leave below the theorem. E.g.: 3pt
  {}% name of font to use in the body of the theorem
  {\parindent}% measure of space to indent
  {}% name of head font
  {.}% punctuation between head and body
  {.5em}% space after theorem head; " " = normal interword space
  {}

\newtheoremstyle{cmchDefinition}% name of the style to be used
  {2pt}% measure of space to leave above the theorem. E.g.: 3pt
  {2pt}% measure of space to leave below the theorem. E.g.: 3pt
  {}% name of font to use in the body of the theorem
  {\parindent}% measure of space to indent
  {}% name of head font
  {.}% punctuation between head and body
  {.5em}% space after theorem head; " " = normal interword space
  {}

\newtheoremstyle{cmchDotlessTheorem}% name of the style to be used
  {3pt}% measure of space to leave above the theorem. E.g.: 3pt
  {3pt}% measure of space to leave below the theorem. E.g.: 3pt
  {\itshape}% name of font to use in the body of the theorem
  {\parindent}% measure of space to indent
  {}% name of head font
  {}% punctuation between head and body
  {.5em}% space after theorem head; " " = normal interword space
  {}

\newtheoremstyle{cmchDotlessDefinition}% name of the style to be used
  {2pt}% measure of space to leave above the theorem. E.g.: 3pt
  {2pt}% measure of space to leave below the theorem. E.g.: 3pt
  {}% name of font to use in the body of the theorem
  {\parindent}% measure of space to indent
  {}% name of head font
  {}% punctuation between head and body
  {.5em}% space after theorem head; " " = normal interword space
  {}

\renewenvironment{proof}{Д\,о\,к\,а\,з\,а\,т\,е\,л\,ь\,с\,т\,в\,о.}{\par}

\theoremstyle{cmchTheorem}
\newtheorem{theorem}{Т\,е\,о\,р\,е\,м\,а}
\newtheorem{lemma}{Л\,е\,м\,м\,а}
\newtheorem{corollary}{С\,л\,е\,д\,с\,т\,в\,и\,е}
\newtheorem{proposition}{П\,р\,е\,д\,л\,о\,ж\,е\,н\,и\,е}

\theoremstyle{cmchDefinition}
\newtheorem{definition}{О\,п\,р\,е\,д\,е\,л\,е\,н\,и\,е}


%
%   Duplicate the symbol after the '\HM' command on the next line
%
\newcommand*{\HM}[1]{#1\nobreak\discretionary{}{\hbox{\(\mathsurround=0pt #1\)}}{}}

\newcommand{\No}{\textnumero}

\newcommand{\articleColonName}[1]{\fancyhead[LO]{#1}}


%
%	Page accounting
%


%\renewcommand{\baselinestretch}{2}
